@@ -7,6 +7,7 @@ import sys
 import logging
 import operator
 from functools import partial
+from StringIO import StringIO
 
 import pkg_resources
 
@@ -19,14 +20,14 @@ from PyQt4.QtGui import (
 )
 
 from PyQt4.QtCore import (
-    Qt, QEvent, QSize, QUrl, QTimer, QFile, QByteArray
+    Qt, QObject, QEvent, QSize, QUrl, QTimer, QFile, QByteArray
 )
 
 from PyQt4.QtNetwork import QNetworkDiskCache
 
 from PyQt4.QtWebKit import QWebView
 
-from PyQt4.QtCore import pyqtProperty as Property
+from PyQt4.QtCore import pyqtProperty as Property, pyqtSignal as Signal
 
 # Compatibility with PyQt < v4.8.3
 from ..utils.qtcompat import QSettings
@@ -41,13 +42,15 @@ from ..help import HelpManager
 
 from .canvastooldock import CanvasToolDock, QuickCategoryToolbar, \
                             CategoryPopupMenu, popup_position_from_source
+from .widgettoolbox import item_text, qvariant_to_object
 from .aboutdialog import AboutDialog
 from .schemeinfo import SchemeInfoDialog
 from .outputview import OutputView
-from .settings import UserSettingsDialog
+from .settings import UserSettingsDialog, category_state
 from .addons import AddOnManagerDialog
 
 from ..document.schemeedit import SchemeEditWidget
+from ..document.quickmenu import SortFilterProxyModel
 
 from ..scheme import widgetsscheme
 from ..scheme.readwrite import scheme_load, sniff_version
@@ -180,12 +183,18 @@ class CanvasMainWindow(QMainWindow):
         self.__first_show = True
 
         self.widget_registry = None
+        # Proxy widget registry model
+        self.__proxy_model = None
 
         self.last_scheme_dir = QDesktopServices.StandardLocation(
             QDesktopServices.DocumentsLocation
         )
+        try:
+            self.recent_schemes = config.recent_schemes()
+        except Exception:
+            log.error("Failed to load recent scheme list.", exc_info=True)
+            self.recent_schemes = []
 
-        self.recent_schemes = config.recent_schemes()
         self.num_recent_schemes = 15
 
         self.open_in_external_browser = False
@@ -227,6 +236,10 @@ class CanvasMainWindow(QMainWindow):
 
         self.scheme_widget = SchemeEditWidget()
         self.scheme_widget.setScheme(widgetsscheme.WidgetsScheme(parent=self))
+        dropfilter = UrlDropEventFilter(self)
+        dropfilter.urlDropped.connect(self.open_scheme_file)
+        self.scheme_widget.setAcceptDrops(True)
+        self.scheme_widget.installEventFilter(dropfilter)
 
         w.layout().addWidget(self.scheme_widget)
 
@@ -242,8 +255,6 @@ class CanvasMainWindow(QMainWindow):
         self.scheme_widget.titleChanged.connect(self.set_document_title)
         self.scheme_widget.modificationChanged.connect(self.setWindowModified)
 
-        self.setWindowIcon(canvas_icons("Get Started.svg"))
-
         # QMainWindow's Dock widget
         self.dock_widget = CollapsibleDockWidget(objectName="main-area-dock")
         self.dock_widget.setFeatures(QDockWidget.DockWidgetMovable | \
@@ -743,19 +754,31 @@ class CanvasMainWindow(QMainWindow):
         """
         if self.widget_registry is not None:
             # Clear the dock widget and popup.
-            pass
+            self.widgets_tool_box.setModel(None)
+            self.quick_category.setModel(None)
+            self.scheme_widget.setRegistry(None)
+            self.help.set_registry(None)
+            self.__proxy_model.deleteLater()
+            self.__proxy_model = None
 
         self.widget_registry = widget_registry
-        self.widgets_tool_box.setModel(widget_registry.model())
-        self.quick_category.setModel(widget_registry.model())
+
+        # Restore category hidden/sort order state
+        proxy = SortFilterProxyModel(self)
+        proxy.setSourceModel(widget_registry.model())
+        self.__proxy_model = proxy
+        self.__update_registry_filters()
+
+        self.widgets_tool_box.setModel(proxy)
+        self.quick_category.setModel(proxy)
 
         self.scheme_widget.setRegistry(widget_registry)
+        self.scheme_widget.quickMenu().setModel(proxy)
 
         self.help.set_registry(widget_registry)
 
         # Restore possibly saved widget toolbox tab states
         settings = QSettings()
-
         state = settings.value("mainwindow/widgettoolbox/state",
                                 defaultValue=QByteArray(),
                                 type=QByteArray)
@@ -1156,9 +1179,26 @@ class CanvasMainWindow(QMainWindow):
         dirname, basename = os.path.split(filename)
         self.last_scheme_dir = dirname
         title = scheme.title or "untitled"
+
+        # First write the scheme to a buffer so we don't truncate an
+        # existing scheme file if `scheme.save_to` raises an error.
+        buffer = StringIO()
         try:
-            scheme.save_to(open(filename, "wb"),
-                           pretty=True, pickle_fallback=True)
+            scheme.save_to(buffer, pretty=True, pickle_fallback=True)
+        except Exception:
+            log.error("Error saving %r to %r", scheme, filename, exc_info=True)
+            message_critical(
+                self.tr('An error occurred while trying to save scheme '
+                        '"%s" to "%s"') % (title, basename),
+                title=self.tr("Error saving %s") % basename,
+                exc_info=True,
+                parent=self
+            )
+            return False
+
+        try:
+            with open(filename, "wb") as f:
+                f.write(buffer.getvalue())
             return True
         except (IOError, OSError) as ex:
             log.error("%s saving '%s'", type(ex).__name__, filename,
@@ -1218,7 +1258,7 @@ class CanvasMainWindow(QMainWindow):
     def documentation(self, *args):
         """Show reference documentation.
         """
-        url = QUrl(LINKS["tutorial"])
+        url = QUrl(LINKS["start-using"])
         QDesktopServices.openUrl(url)
 
     def recent_scheme(self, *args):
@@ -1917,6 +1957,20 @@ class CanvasMainWindow(QMainWindow):
             settings.value("toolbox-dock-use-popover-menu", defaultValue=True,
                            type=bool)
 
+        self.__update_registry_filters()
+
+    def __update_registry_filters(self):
+        if self.widget_registry is None:
+            return
+
+        settings = QSettings()
+        visible_state = {}
+        for cat in self.widget_registry.categories():
+            visible, _ = category_state(cat, settings)
+            visible_state[cat.name] = visible
+        self.__proxy_model.setFilterFunc(
+            category_filter_function(visible_state))
+
 
 def updated_flags(flags, mask, state):
     if state:
@@ -1944,3 +1998,50 @@ def index(sequence, *what, **kwargs):
         if predicate(what, item_key):
             return i
     raise ValueError("%r not in sequence" % what)
+
+from ..registry import qt
+
+
+def category_filter_function(state):
+    def category_filter(index):
+        if index.parent().isValid():
+            # Is not a category item
+            return True
+
+        # Get the default visibility state
+        desc = index.data(qt.QtWidgetRegistry.CATEGORY_DESC_ROLE)
+        desc = qvariant_to_object(desc)
+        if isinstance(desc, qt.CategoryDescription):
+            visible = not desc.hidden
+        else:
+            visible = True
+        category = item_text(index)
+        return state.get(category, visible)
+    return category_filter
+
+
+class UrlDropEventFilter(QObject):
+    urlDropped = Signal(QUrl)
+
+    def eventFilter(self, obj, event):
+        etype = event.type()
+        if  etype == QEvent.DragEnter or etype == QEvent.DragMove:
+            mime = event.mimeData()
+            if mime.hasUrls() and len(mime.urls()) == 1:
+                url = mime.urls()[0]
+                if url.scheme() == "file":
+                    filename = unicode(url.toLocalFile())
+                    _, ext = os.path.splitext(filename)
+                    if ext == ".ows":
+                        event.acceptProposedAction()
+                        return True
+
+        elif etype == QEvent.Drop:
+            mime = event.mimeData()
+            urls = mime.urls()
+            if urls:
+                url = urls[0]
+                self.urlDropped.emit(url)
+                return True
+
+        return QObject.eventFilter(self, obj, event)
