@@ -34,6 +34,7 @@ from ..gui.utils import message_information, disabled
 from ..scheme import (
     scheme, signalmanager, SchemeNode, SchemeLink, BaseSchemeAnnotation
 )
+from ..scheme import widgetsscheme
 from ..canvas.scene import CanvasScene
 from ..canvas.view import CanvasView
 from ..canvas import items
@@ -977,6 +978,10 @@ class SchemeEditWidget(QWidget):
             if event.type() == QEvent.WhatsThisClicked:
                 # Re post the event
                 self.__showHelpFor(event.href())
+            elif event.type() == \
+                    widgetsscheme.ActivateParentEvent.ActivateParent:
+                self.window().activateWindow()
+                self.window().raise_()
 
         return QWidget.eventFilter(self, obj, event)
 
@@ -1236,6 +1241,7 @@ class SchemeEditWidget(QWidget):
         widget = self.scheme().widget_for_node(node)
         widget.show()
         widget.raise_()
+        widget.activateWindow()
 
     def __onNodePositionChanged(self, item, pos):
         node = self.__scene.node_for_item(item)
