@@ -67,6 +67,7 @@ class SchemeNode(QObject):
         self.__position = position or (0, 0)
         self.__progress = -1
         self.__processing_state = 0
+        self.__status_message = ""
         self.__state_messages = {}
         self.properties = properties or {}
 
@@ -193,6 +194,20 @@ class SchemeNode(QObject):
     tool_tip = Property(str, fset=set_tool_tip,
                         fget=tool_tip)
 
+    #: The node's status tip has changes
+    status_message_changed = Signal(unicode)
+
+    def set_status_message(self, text):
+        if self.__status_message != text:
+            self.__status_message = text
+            self.status_message_changed.emit(text)
+
+    def status_message(self):
+        return self.__status_message
+
+    #: The node's state message has changed
+    state_message_changed = Signal(UserMessage)
+
     def set_state_message(self, message):
         """
         Set a message to be displayed by a scheme view for this node.
@@ -202,11 +217,13 @@ class SchemeNode(QObject):
             del self.__state_messages[message.message_id]
 
         self.__state_messages[message.message_id] = message
-
         self.state_message_changed.emit(message)
 
-    #: The node's state message has changed
-    state_message_changed = Signal(UserMessage)
+    def state_messages(self):
+        """
+        Return a list of all state messages.
+        """
+        return self.__state_messages.values()
 
     def __str__(self):
         return u"SchemeNode(description_id=%s, title=%r, ...)" % \
