@@ -18,8 +18,10 @@ companion :class:`WidgetsSignalManager` class.
 """
 import sys
 import logging
+import traceback
 
 import sip
+
 from PyQt4.QtGui import (
     QShortcut, QKeySequence, QWhatsThisClickedEvent, QWidget
 )
@@ -184,6 +186,8 @@ class WidgetManager(QObject):
         self.__widget_for_node[node] = widget
         self.__node_for_widget[widget] = node
 
+        self.__initialize_widget_state(node, widget)
+
         self.widget_for_node_added.emit(node, widget)
 
     def remove_widget_for_node(self, node):
@@ -193,9 +197,13 @@ class WidgetManager(QObject):
         widget = self.widget_for_node(node)
 
         self.__widgets.remove(widget)
+
         del self.__widget_for_node[node]
         del self.__node_for_widget[widget]
 
+        node.title_changed.disconnect(widget.setCaption)
+        widget.progressBarValueChanged.disconnect(node.set_progress)
+
         self.widget_for_node_removed.emit(node, widget)
 
         self._delete_widget(widget)
@@ -219,35 +227,74 @@ class WidgetManager(QObject):
             self.__delay_delete.add(widget)
         else:
             widget.deleteLater()
+            del self.__widget_processing_state[widget]
 
     def create_widget_instance(self, node):
         """
         Create a OWWidget instance for the node.
+
+        If a widget cannot be created due to an error a dummy widget
+        with an error text is created in it's place.
+
         """
         desc = node.description
-        klass = name_lookup(desc.qualified_name)
+        klass = widget = None
+        initialized = False  # Was the widget already initialized
+        # First try to actually retrieve the class.
+        try:
+            klass = name_lookup(desc.qualified_name)
+        except (ImportError, AttributeError):
+            sys.excepthook(*sys.exc_info())
+            msg = traceback.format_exc()
+            msg = "Could not import {0!r}\n\n{1}".format(
+                node.description.qualified_name, msg
+            )
+            widget = mock_error_owwidget(node, msg)
+            initialized = True
 
-        log.info("Creating %r instance.", klass)
-        widget = klass.__new__(
-            klass,
-            _owInfo=True,
-            _owWarning=True,
-            _owError=True,
-            _owShowStatus=True,
-            _useContexts=True,
-            _category=desc.category,
-            _settingsFromSchema=node.properties
-        )
+        if widget is None:
+            log.info("Creating %r instance.", klass)
+            widget = klass.__new__(
+                klass,
+                _owInfo=True,
+                _owWarning=True,
+                _owError=True,
+                _owShowStatus=True,
+                _useContexts=True,
+                _category=desc.category,
+                _settingsFromSchema=node.properties
+            )
+            initialized = False
 
         # Init the node/widget mapping and state before calling __init__
         # Some OWWidgets might already send data in the constructor
         # (should this be forbidden? Raise a warning?) triggering the signal
         # manager which would request the widget => node mapping or state
+
         self.__widget_for_node[node] = widget
         self.__node_for_widget[widget] = node
         self.__widget_processing_state[widget] = 0
 
-        widget.__init__(None, self.signal_manager())
+        if not initialized:
+            try:
+                widget.__init__(None, self.signal_manager())
+            except Exception:
+                sys.excepthook(*sys.exc_info())
+                msg = traceback.format_exc()
+                msg = "Could not create {0!r}\n\n{1}".format(
+                    node.description.name, msg
+                )
+                # remove state tracking
+                del self.__widget_for_node[node]
+                del self.__node_for_widget[widget]
+                del self.__widget_processing_state[widget]
+
+                widget = mock_error_owwidget(node, msg)
+
+                self.__widget_for_node[node] = widget
+                self.__node_for_widget[widget] = node
+                self.__widget_processing_state[widget] = 0
+
         widget.setCaption(node.title)
         widget.widgetInfo = desc
 
@@ -262,6 +309,10 @@ class WidgetManager(QObject):
         # Widget's info/warning/error messages.
         widget.widgetStateChanged.connect(self.__on_widget_state_changed)
 
+        # Widget's statusTip
+        node.set_status_message(widget.statusMessage())
+        widget.statusMessageChanged.connect(node.set_status_message)
+
         # Widget's progress bar value state.
         widget.progressBarValueChanged.connect(node.set_progress)
 
@@ -278,10 +329,21 @@ class WidgetManager(QObject):
             # A widget can already enter blocking state in __init__
             self.__widget_processing_state[widget] |= self.BlockingUpdate
 
+        if widget.processingState != 0:
+            # It can also start processing (initialization of resources, ...)
+            self.__widget_processing_state[widget] |= self.ProcessingUpdate
+            node.set_processing_state(1)
+            node.set_progress(widget.progressBarValue)
+
         # Install a help shortcut on the widget
         help_shortcut = QShortcut(QKeySequence("F1"), widget)
         help_shortcut.activated.connect(self.__on_help_request)
 
+        # Up shortcut (activate/open parent)
+        up_shortcut = QShortcut(
+            QKeySequence(Qt.ControlModifier + Qt.Key_Up), widget)
+        up_shortcut.activated.connect(self.__on_activate_parent)
+
         return widget
 
     def node_processing_state(self, node):
@@ -339,6 +401,24 @@ class WidgetManager(QObject):
             event = QWhatsThisClickedEvent(url)
             QCoreApplication.sendEvent(self.scheme(), event)
 
+    def __on_activate_parent(self):
+        """
+        Activate parent shortcut was pressed.
+        """
+        event = ActivateParentEvent()
+        QCoreApplication.sendEvent(self.scheme(), event)
+
+    def __initialize_widget_state(self, node, widget):
+        """
+        Initialize the tracked info/warning/error message state.
+        """
+        for message_type, state in widget.widgetState.items():
+            for message_id, message_value in state.items():
+                message = user_message_from_state(
+                    widget, message_type, message_id, message_value)
+
+                node.set_state_message(message)
+
     def __on_widget_state_changed(self, message_type, message_id,
                                   message_value):
         """
@@ -356,25 +436,9 @@ class WidgetManager(QObject):
         except KeyError:
             pass
         else:
-            message_type = str(message_type)
-            if message_type == "Info":
-                contents = widget.widgetStateToHtml(True, False, False)
-                level = UserMessage.Info
-            elif message_type == "Warning":
-                contents = widget.widgetStateToHtml(False, True, False)
-                level = UserMessage.Warning
-            elif message_type == "Error":
-                contents = widget.widgetStateToHtml(False, False, True)
-                level = UserMessage.Error
-            else:
-                raise ValueError("Invalid message_type: %r" % message_type)
+            message = user_message_from_state(
+                widget, str(message_type), message_id, message_value)
 
-            if not contents:
-                contents = None
-
-            message = UserMessage(contents, severity=level,
-                                  message_id=message_type,
-                                  data={"content-type": "text/html"})
             node.set_state_message(message)
 
     def __on_processing_state_changed(self, state):
@@ -455,6 +519,29 @@ class WidgetManager(QObject):
             del self.__widget_processing_state[widget]
 
 
+def user_message_from_state(widget, message_type, message_id, message_value):
+    message_type = str(message_type)
+    if message_type == "Info":
+        contents = widget.widgetStateToHtml(True, False, False)
+        level = UserMessage.Info
+    elif message_type == "Warning":
+        contents = widget.widgetStateToHtml(False, True, False)
+        level = UserMessage.Warning
+    elif message_type == "Error":
+        contents = widget.widgetStateToHtml(False, False, True)
+        level = UserMessage.Error
+    else:
+        raise ValueError("Invalid message_type: %r" % message_type)
+
+    if not contents:
+        contents = None
+
+    message = UserMessage(contents, severity=level,
+                          message_id=message_type,
+                          data={"content-type": "text/html"})
+    return message
+
+
 class WidgetsSignalManager(SignalManager):
     """
     A signal manager for a WidgetsScheme.
@@ -530,9 +617,6 @@ class WidgetsSignalManager(SignalManager):
                          widget)
             return
 
-        if widget.processingHandler:
-            widget.processingHandler(widget, 1)
-
         app = QCoreApplication.instance()
 
         for signal in signals:
@@ -580,9 +664,6 @@ class WidgetsSignalManager(SignalManager):
         finally:
             app.restoreOverrideCursor()
 
-        if widget.processingHandler:
-            widget.processingHandler(widget, 0)
-
     def scheduleSignalProcessing(self, widget=None):
         """
         Back compatibility with old orngSignalManager.
@@ -630,9 +711,9 @@ class WidgetsSignalManager(SignalManager):
         source_node = sink_node = None
 
         if widgetFrom is not None:
-            source_node = scheme.node_for_widget[widgetFrom]
+            source_node = scheme.node_for_widget(widgetFrom)
         if widgetTo is not None:
-            sink_node = scheme.node_for_widget[widgetTo]
+            sink_node = scheme.node_for_widget(widgetTo)
 
         candidates = scheme.find_links(source_node=source_node,
                                        sink_node=sink_node)
@@ -790,3 +871,35 @@ class SignalWrapper(object):
         else:
             # Might be running stand alone without a manager.
             self.method(*args)
+
+
+def mock_error_owwidget(node, message):
+    """
+    Create a mock OWWidget instance for `node`.
+
+    :type node: SchemeNode
+
+    """
+    from Orange.OrangeWidgets.OWWidget import _DummyOWWidget
+
+    widget = _DummyOWWidget()
+    widget.widgetInfo = node.description
+    widget._settingsFromSchema = node.properties
+
+    for link in node.description.inputs:
+        handler = link.handler
+        if handler.startswith("self."):
+            _, handler = handler.split(".", 1)
+
+        setattr(widget, handler, lambda *args: None)
+
+    widget.setBlocking(True)
+    widget.setErrorMessage(message)
+    return widget
+
+
+class ActivateParentEvent(QEvent):
+    ActivateParent = QEvent.registerEventType()
+
+    def __init__(self):
+        QEvent.__init__(self, self.ActivateParent)
