@@ -1,26 +1,23 @@
-"""
-<name>Rank</name>
-<description>Ranks and filters attributes by their relevance.</description>
-<icon>icons/Rank.svg</icon>
-<contact>Janez Demsar (janez.demsar(@at@)fri.uni-lj.si)</contact>
-<priority>1102</priority>
-"""
-
+import OWGUI
+import Orange
+import pkg_resources
 from collections import namedtuple
 from functools import partial
-
-import pkg_resources
-
 from OWWidget import *
-
-import OWGUI
-
-import Orange
 from Orange.feature import scoring
-from Orange.regression import earth
 from Orange.classification import svm
 from Orange.ensemble import forest
 
+NAME = "Rank"
+DESCRIPTION = "Ranks and filters data features by their relevance."
+LONG_DESCRIPTION = ""
+ICON = "icons/Rank.svg"
+PRIORITY = 1102
+AUTHOR = "Janez Demsar"
+AUTHOR_EMAIL = "janez.demsar(@at@)fri.uni-lj.si"
+INPUTS = [("Data", Orange.data.Table, "setData")]
+OUTPUTS = [("Reduced Data", Orange.data.Table, Default + Single)]
+
 
 def is_discrete(var):
     return isinstance(var, Orange.feature.Discrete)
@@ -45,26 +42,6 @@ def table(shape, fill=None):
 
 
 MEASURE_PARAMS = {
-    earth.ScoreEarthImportance: [
-        {"name": "t",
-         "type": int,
-         "display_name": "Num. models.",
-         "range": (1, 20),
-         "default": 10,
-         "doc": "Number of models to train for feature scoring."},
-        {"name": "terms",
-         "type": int,
-         "display_name": "Max. num of terms",
-         "range": (3, 200),
-         "default": 10,
-         "doc": "Maximum number of terms in the forward pass"},
-        {"name": "degree",
-         "type": int,
-         "display_name": "Max. term degree",
-         "range": (1, 3),
-         "default": 2,
-         "doc": "Maximum degree of terms included in the model."}
-    ],
     scoring.Relief: [
         {"name": "k",
          "type": int,
@@ -157,10 +134,6 @@ SCORES = [
     score_meta(
         "Random Forests", "RF", forest.ScoreFeature,
         params=MEASURE_PARAMS[forest.ScoreFeature]),
-    score_meta(
-        "Earth Importance", "Earth imp.", earth.ScoreEarthImportance,
-        params=MEASURE_PARAMS[earth.ScoreEarthImportance],
-    )
 ]
 
 _DEFAULT_SELECTED = set(m.name for m in SCORES[:6])
@@ -218,7 +191,7 @@ class OWRank(OWWidget):
     settingsList = [
         "nDecimals", "nIntervals", "sortBy", "nSelected",
         "selectMethod", "autoApply", "showDistributions",
-        "distColorRgb"
+        "distColorRgb", "selectedMeasures"
     ]
 
     def __init__(self, parent=None, signalManager=None):
