@@ -39,6 +39,10 @@ class singleClassLiftCurveGraph(singleClassROCgraph):
         self.performanceLineCKey.setYAxis(QwtPlot.yRight)
         self.performanceLineCKey.setSymbol(QwtSymbol())
 
+        curves = self.mergedCKeys + self.mergedConvexCKeys
+        for curve in curves:
+            curve.setItemAttribute(QwtPlotItem.AutoScale, True)
+
     def setTestSetData(self, splitByIterations, targetClass):
         self.splitByIterations = splitByIterations
         ## generate the "base" unmodified Lift curves
@@ -408,11 +412,16 @@ class OWLiftCurve(OWROC):
                 self.defaultPerfLinePValues.append(v)
                 self.pvalueList.append( v)
 
-            self.targetClass = 0 ## select first target
+            self.targetClass = 0  # select first class as default target
+            self.openContext("", self.dres)
+
+            # Update target class and selected classifiers from
+            # context settings
             self.target()
+            self.classifiersSelectionChange()
+
         else:
             self.classifierColor = None
-        self.openContext("", self.dres)
         self.performanceTabCosts.setEnabled(1)
         self.setDefaultPValues()
 
