@@ -72,6 +72,14 @@ def has_discrete_values(domain):
                for at in domain.features)
 
 
+@deprecated_members(
+    {"removeSingular": "remove_singular",
+     "weightID": "weight_id",
+     "stepwiseLR": "stepwise_lr",
+     "addCrit": "add_crit",
+     "deleteCrit": "delete_crit",
+     "numFeatures": "num_features",
+     "removeMissing": "remove_missing"})
 class LogRegLearner(Orange.classification.Learner):
     """ Logistic regression learner.
 
@@ -170,14 +178,6 @@ class LogRegLearner(Orange.classification.Learner):
             lr = learner.fit_model(data, weight)
         return lr
 
-LogRegLearner = deprecated_members({"removeSingular": "remove_singular",
-                                    "weightID": "weight_id",
-                                    "stepwiseLR": "stepwise_lr",
-                                    "addCrit": "add_crit",
-                                    "deleteCrit": "delete_crit",
-                                    "numFeatures": "num_features",
-                                    "removeMissing": "remove_missing"
-                                    })(LogRegLearner)
 
 class UnivariateLogRegLearner(Orange.classification.Learner):
     def __new__(cls, data=None, **argkw):
@@ -215,8 +215,9 @@ class UnivariateLogRegClassifier(Orange.classification.Classifier):
         # classification not implemented yet. For now its use is only to
         # provide regression coefficients and its statistics
         raise NotImplemented
-    
 
+
+@deprecated_members({"removeSingular": "remove_singular"})
 class LogRegLearnerGetPriors(object):
     def __new__(cls, data=None, weight_id=0, **argkw):
         self = object.__new__(cls)
@@ -340,10 +341,8 @@ class LogRegLearnerGetPriors(object):
         return (orig_model, betas_ap)
         #return (bayes_prior,orig_model.beta[examples.domain.class_var],logistic_prior)
 
-LogRegLearnerGetPriors = deprecated_members({"removeSingular":
-                                                 "remove_singular"}
-)(LogRegLearnerGetPriors)
 
+@deprecated_members({"removeSingular": "remove_singular"})
 class LogRegLearnerGetPriorsOneTable:
     @deprecated_keywords({"removeSingular": "remove_singular"})
     def __init__(self, remove_singular=0, **kwds):
@@ -443,10 +442,6 @@ class LogRegLearnerGetPriorsOneTable:
         return (orig_model, betas_ap)
         #return (bayes_prior,orig_model.beta[data.domain.class_var],logistic_prior)
 
-LogRegLearnerGetPriorsOneTable = deprecated_members({"removeSingular":
-                                                         "remove_singular"}
-)(LogRegLearnerGetPriorsOneTable)
-
 
 ######################################
 #### Fitters for logistic regression (logreg) learner ####
@@ -703,9 +698,12 @@ def get_likelihood(fitter, data):
        return likelihood
     else:
        return -100*len(data)
-        
 
 
+@deprecated_members(
+    {"addCrit": "add_crit",
+     "deleteCrit": "delete_crit",
+     "numFeatures": "num_features"})
 class StepWiseFSS(object):
   """
   A learning algorithm for logistic regression that implements a
@@ -884,11 +882,11 @@ class StepWiseFSS(object):
 
     return attr
 
-StepWiseFSS = deprecated_members({"addCrit": "add_crit",
-                                   "deleteCrit": "delete_crit",
-                                   "numFeatures": "num_features"})(StepWiseFSS)
-
 
+@deprecated_members(
+    {"addCrit": "add_crit",
+     "deleteCrit": "delete_crit",
+     "numFeatures": "num_features"})
 class StepWiseFSSFilter(object):
     def __new__(cls, data=None, **argkw):
         self = object.__new__(cls)
@@ -911,11 +909,6 @@ class StepWiseFSSFilter(object):
             delete_crit= self.delete_crit, num_features= self.num_features)
         return data.select(Orange.data.Domain(attr, data.domain.class_var))
 
-StepWiseFSSFilter = deprecated_members({"addCrit": "add_crit",
-                                        "deleteCrit": "delete_crit",
-                                        "numFeatures": "num_features"})\
-    (StepWiseFSSFilter)
-
 
 ####################################
 ##  PROBABILITY CALCULATIONS
@@ -1026,12 +1019,17 @@ Logistic regression learner from LIBLINEAR
 
 
 class LibLinearLogRegLearner(Orange.core.LinearLearner):
-    """A logistic regression learner from `LIBLINEAR`_.
+    """
+    A logistic regression learner from `LIBLINEAR`_.
 
     Supports L2 regularized learning.
 
     .. _`LIBLINEAR`: http://www.csie.ntu.edu.tw/~cjlin/liblinear/
 
+    .. note::
+        Unlike :class:`LogRegLearner` this one supports multi-class
+        classification using one vs. rest strategy.
+
     """
 
     L2R_LR = Orange.core.LinearLearner.L2R_LR
@@ -1084,6 +1082,20 @@ class LibLinearLogRegLearner(Orange.core.LinearLearner):
             setattr(self, name, value)
 
     def __call__(self, data, weight_id=None):
+        """
+        Return a classifier trained on the `data` (`weight_id` is ignored).
+
+        :param Orange.data.Table data:
+            Training data set.
+        :param int weight_id:
+            Ignored.
+        :rval: Orange.core.LinearClassifier
+
+        .. note::
+            The :class:`Orange.core.LinearClassifier` is same class as
+            :class:`Orange.classification.svm.LinearClassifier`.
+
+        """
         if not isinstance(data.domain.class_var, Orange.feature.Discrete):
             raise TypeError("Can only learn a discrete class.")
 
