@@ -46,7 +46,7 @@ from Orange.utils import deprecated_keywords
 from Orange.utils import deprecated_members
 
 
-
+@deprecated_members({"weightID": "weight_id", "targetClass": "target_class"})
 class LaplaceEvaluator(Evaluator):
     """
     Laplace's rule of succession.
@@ -63,10 +63,8 @@ class LaplaceEvaluator(Evaluator):
         else:
             return (max(rule.class_distribution) + 1) / (sumDist + len(data.domain.class_var.values))
 
-LaplaceEvaluator = deprecated_members({"weightID": "weight_id",
-                                       "targetClass": "target_class"})(LaplaceEvaluator)
-
 
+@deprecated_members({"weightID": "weight_id", "targetClass": "target_class"})
 class WRACCEvaluator(Evaluator):
     """
     Weighted relative accuracy.
@@ -90,10 +88,8 @@ class WRACCEvaluator(Evaluator):
             return pRule * (pTruePositive - pClass)
         else: return (pTruePositive - pClass) / max(pRule, 1e-6)
 
-WRACCEvaluator = deprecated_members({"weightID": "weight_id",
-                                     "targetClass": "target_class"})(WRACCEvaluator)
-
 
+@deprecated_members({"weightID": "weight_id", "targetClass": "target_class"})
 class MEstimateEvaluator(Evaluator):
     """
     Rule evaluator using m-estimate of probability rule evaluation function.
@@ -120,10 +116,17 @@ class MEstimateEvaluator(Evaluator):
             p = p / (rule.class_distribution.abs + self.m)
         return p
 
-MEstimateEvaluator = deprecated_members({"weightID": "weight_id",
-                                         "targetClass": "target_class"})(MEstimateEvaluator)
-
 
+@deprecated_members(
+    {"beamWidth": "beam_width",
+     "ruleFinder": "rule_finder",
+     "ruleStopping": "rule_stopping",
+     "dataStopping": "data_stopping",
+     "coverAndRemove": "cover_and_remove",
+     "storeInstances": "store_instances",
+     "targetClass": "target_class",
+     "baseRules": "base_rules",
+     "weightID": "weight_id"})
 class CN2Learner(RuleLearner):
     """
     Classical CN2 inducer (Clark and Niblett; 1988) that constructs a
@@ -165,17 +168,8 @@ class CN2Learner(RuleLearner):
         rules = cl.rules
         return CN2Classifier(rules, instances, weight)
 
-CN2Learner = deprecated_members({"beamWidth": "beam_width",
-                     "ruleFinder": "rule_finder",
-                     "ruleStopping": "rule_stopping",
-                     "dataStopping": "data_stopping",
-                     "coverAndRemove": "cover_and_remove",
-                     "storeInstances": "store_instances",
-                     "targetClass": "target_class",
-                     "baseRules": "base_rules",
-                     "weightID": "weight_id"})(CN2Learner)
-
 
+@deprecated_members({"resultType": "result_type", "beamWidth": "beam_width"})
 class CN2Classifier(RuleClassifier):
     """
     Classical CN2 classifier (Clark and Niblett; 1988) that predicts a
@@ -241,10 +235,17 @@ class CN2Classifier(RuleClassifier):
             ret_str += "ELSE " + rule_to_string(r) + " " + str(r.class_distribution) + "\n"
         return ret_str
 
-CN2Classifier = deprecated_members({"resultType": "result_type",
-                                    "beamWidth": "beam_width"})(CN2Classifier)
-
 
+@deprecated_members(
+    {"beamWidth": "beam_width",
+     "ruleFinder": "rule_finder",
+     "ruleStopping": "rule_stopping",
+     "dataStopping": "data_stopping",
+     "coverAndRemove": "cover_and_remove",
+     "storeInstances": "store_instances",
+     "targetClass": "target_class",
+     "baseRules": "base_rules",
+     "weightID": "weight_id"})
 class CN2UnorderedLearner(RuleLearner):
     """
     Unordered CN2 (Clark and Boswell; 1991) induces a set of unordered
@@ -310,16 +311,6 @@ class CN2UnorderedLearner(RuleLearner):
             progress(1.0, None)
         return CN2UnorderedClassifier(rules, instances, weight_id)
 
-CN2UnorderedLearner = deprecated_members({"beamWidth": "beam_width",
-                     "ruleFinder": "rule_finder",
-                     "ruleStopping": "rule_stopping",
-                     "dataStopping": "data_stopping",
-                     "coverAndRemove": "cover_and_remove",
-                     "storeInstances": "store_instances",
-                     "targetClass": "target_class",
-                     "baseRules": "base_rules",
-                     "weightID": "weight_id"})(CN2UnorderedLearner)
-
 
 class CN2UnorderedClassifier(RuleClassifier):
     """
@@ -465,6 +456,17 @@ class CN2SDUnorderedLearner(CN2UnorderedLearner):
         return classifier
 
 
+@deprecated_members(
+    {"beamWidth": "beam_width",
+     "ruleFinder": "rule_finder",
+     "ruleStopping": "rule_stopping",
+     "dataStopping": "data_stopping",
+     "coverAndRemove": "cover_and_remove",
+     "storeInstances": "store_instances",
+     "targetClass": "target_class",
+     "baseRules": "base_rules",
+     "weightID": "weight_id",
+     "argumentID": "argument_id"})
 class ABCN2(RuleLearner):
     """
     Argument-based CN2 that uses EVC for evaluation
@@ -958,16 +960,6 @@ class ABCN2(RuleLearner):
         rule = cn2_learner.rule_finder(examples, weight_id, 0, RuleList())
         return rule.filter.conditions
 
-ABCN2 = deprecated_members({"beamWidth": "beam_width",
-                     "ruleFinder": "rule_finder",
-                     "ruleStopping": "rule_stopping",
-                     "dataStopping": "data_stopping",
-                     "coverAndRemove": "cover_and_remove",
-                     "storeInstances": "store_instances",
-                     "targetClass": "target_class",
-                     "baseRules": "base_rules",
-                     "weightID": "weight_id",
-                     "argumentID": "argument_id"})(ABCN2)
 
 class CN2EVCUnorderedLearner(ABCN2):
     """
@@ -1606,6 +1598,9 @@ class CoversArguments:
     oneSelectorToCover = staticmethod(oneSelectorToCover)
 
 
+@deprecated_members(
+    {"notAllowedSelectors": "not_allowed_selectors",
+     "argumentID": "argument_id"})
 class SelectorAdder(BeamRefiner):
     """
     Selector adder, this function is a refiner function:
@@ -1701,11 +1696,10 @@ class SelectorAdder(BeamRefiner):
         tempRule.filterAndStore(oldRule.examples, oldRule.weightID, target_class)
         return tempRule
 
-SelectorAdder = deprecated_members({"notAllowedSelectors": "not_allowed_selectors",
-                     "argumentID": "argument_id"})(SelectorAdder)
 
 # This filter is the ugliest code ever! Problem is with Orange, I had some problems with inheriting deepCopy
 # I should take another look at it.
+@deprecated_members({"argumentID": "argument_id"})
 class ArgFilter(Orange.core.Filter):
     """ This class implements AB-covering principle. """
     def __init__(self, argument_id=None, filter = Orange.core.Filter_values(), arg_example = None):
@@ -1763,7 +1757,7 @@ class ArgFilter(Orange.core.Filter):
         newFilter.indices = self.indices[:]
         newFilter.arg_example = self.arg_example
         return newFilter
-ArgFilter = deprecated_members({"argumentID": "argument_id"})(ArgFilter)
+
 
 class SelectorArgConditions(BeamRefiner):
     """
@@ -1822,7 +1816,7 @@ class CrossValidation:
         self.random_generator = random_generator
 
     def __call__(self, learner, examples, weight):
-        res = orngTest.crossValidation([learner], (examples, weight), folds=self.folds, random_generator=self.random_generator)
+        res = Orange.evaluation.testing.cross_validation([learner], (examples, weight), folds=self.folds, random_generator=self.random_generator)
         return self.get_prob_from_res(res, examples)
 
     def get_prob_from_res(self, res, examples):
@@ -1835,6 +1829,7 @@ class CrossValidation:
         return prob_dist
 
 
+@deprecated_members({"sortRules": "sort_rules"})
 class PILAR:
     """
     PILAR (Probabilistic improvement of learning algorithms with rules).
@@ -1905,9 +1900,8 @@ class PILAR:
                 new_rules.append(bestRule)
         return new_rules
 
-PILAR = deprecated_members({"sortRules": "sort_rules"})(PILAR)
-
 
+@deprecated_members({"defaultClassIndex": "default_class_index"})
 class RuleClassifier_bestRule(RuleClassifier):
     """
     A very simple classifier, it takes the best rule of each class and
@@ -1971,5 +1965,3 @@ class RuleClassifier_bestRule(RuleClassifier):
         if result_type == Orange.classification.Classifier.GetProbabilities:
           return final_dist
         return (final_dist.modus(), final_dist)
-
-RuleClassifier_bestRule = deprecated_members({"defaultClassIndex": "default_class_index"})(RuleClassifier_bestRule)
