@@ -121,7 +121,7 @@ def discretize_domain(data, remove_unused_values = 1, number_of_intervals = 2):
     equiN if we don't have a class or class is continuous).
     """
     entro_disc = preprocess.EntropyDiscretization()
-    equi_disc  = preprocess.EquiNDiscretization(number_of_intervals=number_of_intervals)
+    equi_disc = preprocess.EquiNDiscretization(n=number_of_intervals)
     disc_attrs = []
 
     classname = (data and len(data) > 0 and data.domain.class_var and
@@ -170,11 +170,50 @@ def discretize_domain(data, remove_unused_values = 1, number_of_intervals = 2):
             warnings.warn("Could not discretize %s attribute. %s" %
                           (attr.name, ex.message))
 
-    if classname: disc_attrs.append(data.domain.class_var)
+    if classname:
+        disc_attrs.append(data.domain.class_var)
     d2 = data.translate(disc_attrs, True)
     return d2
 
 
+@deprecated_members(
+    {"rawData": "raw_data",
+     "rawSubsetData": "raw_subset_data",
+     "attributeNames": "attribute_names",
+     "attributeNameIndex": "attribute_name_index",
+     "attributeFlipInfo": "attribute_flip_info",
+     "dataHasClass": "data_has_class",
+     "dataHasContinuousClass": "data_has_continuous_class",
+     "dataHasDiscreteClass": "data_has_discrete_class",
+     "dataClassName": "data_class_name",
+     "dataDomain": "data_domain",
+     "dataClassIndex": "data_class_index",
+     "haveData": "have_data",
+     "haveSubsetData": "have_subset_data",
+     "jitterSize": "jitter_size",
+     "jitterContinuous": "jitter_continuous",
+     "attrValues": "attr_values",
+     "domainDataStat": "domain_data_stat",
+     "originalData": "original_data",
+     "originalSubsetData": "original_subset_data",
+     "scaledData": "scaled_data",
+     "scaledSubsetData": "scaled_subset_data",
+     "noJitteringScaledData": "no_jittering_scaled_data",
+     "noJitteringScaledSubsetData": "no_jittering_scaled_subset_data",
+     "validDataArray": "valid_data_array",
+     "validSubsetDataArray": "valid_subset_data_array",
+     "mergeDataSets": "merge_data_sets",
+     "rescaleData": "rescale_data",
+     "setData": "set_data",
+     "scaleExampleValue": "scale_example_value",
+     "getAttributeLabel": "get_attribute_label",
+     "flipAttribute": "flip_attribute",
+     "getMinMaxVal": "get_min_max_val",
+     "getValidList": "get_valid_list",
+     "getValidSubsetList": "get_valid_subset_list",
+     "getValidIndices": "get_valid_indices",
+     "getValidSubsetIndices": "get_valid_subset_indices",
+     "rndCorrection": "rnd_correction"})
 class ScaleData:
     def __init__(self):
         self.raw_data = None           # input data
@@ -367,7 +406,8 @@ class ScaleData:
         rand_seeds = random.random_integers(0, sys.maxint - 1, size=len(data.domain))
         for index, rseed in zip(range(len(data.domain)), rand_seeds):
             # Need to use a different seed for each feature
-            random = numpy.random.RandomState(seed=rseed)
+            # Note in numpy 1.9.x the seed must fit in a uint32_t
+            random = numpy.random.RandomState(seed=rseed % (2 ** 32 - 1))
             attr = data.domain[index]
             if attr.var_type == Orange.core.VarTypes.Discrete:
                 scaled_data[index] += (self.jitter_size/(50.0*max(1,len(attr.values))))*\
@@ -514,45 +554,6 @@ class ScaleData:
     
     rndCorrection = rnd_correction
 
-ScaleData = deprecated_members({"rawData": "raw_data",
-                                "rawSubsetData": "raw_subset_data",
-                                "attributeNames": "attribute_names",
-                                "attributeNameIndex": "attribute_name_index",
-                                "attributeFlipInfo": "attribute_flip_info",
-                                "dataHasClass": "data_has_class",
-                                "dataHasContinuousClass": "data_has_continuous_class",
-                                "dataHasDiscreteClass": "data_has_discrete_class",
-                                "dataClassName": "data_class_name",
-                                "dataDomain": "data_domain",
-                                "dataClassIndex": "data_class_index",
-                                "haveData": "have_data",
-                                "haveSubsetData": "have_subset_data",
-                                "jitterSize": "jitter_size",
-                                "jitterContinuous": "jitter_continuous",
-                                "attrValues": "attr_values",
-                                "domainDataStat": "domain_data_stat",
-                                "originalData": "original_data",
-                                "originalSubsetData": "original_subset_data",
-                                "scaledData": "scaled_data",
-                                "scaledSubsetData": "scaled_subset_data",
-                                "noJitteringScaledData": "no_jittering_scaled_data",
-                                "noJitteringScaledSubsetData": "no_jittering_scaled_subset_data",
-                                "validDataArray": "valid_data_array",
-                                "validSubsetDataArray": "valid_subset_data_array",
-                                "mergeDataSets": "merge_data_sets",
-                                "rescaleData": "rescale_data",
-                                "setData": "set_data",
-                                "scaleExampleValue": "scale_example_value",
-                                "getAttributeLabel": "get_attribute_label",
-                                "flipAttribute": "flip_attribute",
-                                "getMinMaxVal": "get_min_max_val",
-                                "getValidList": "get_valid_list",
-                                "getValidSubsetList": "get_valid_subset_list",
-                                "getValidIndices": "get_valid_indices",
-                                "getValidSubsetIndices": "get_valid_subset_indices",
-                                "rndCorrection": "rnd_correction",
-                                })(ScaleData)
-
 
 def jitter_array(array, ratio=0.01, axis=0, rand_seed=None):
     """
@@ -586,6 +587,20 @@ def jitter_array(array, ratio=0.01, axis=0, rand_seed=None):
     return array
 
 
+@deprecated_members(
+    {"setAnchors": "set_anchors",
+     "createAnchors": "create_anchors",
+     "createXAnchors": "create_xanchors",
+     "createYAnchors": "create_yanchors",
+     "saveProjectionAsTabData": "save_projection_as_tab_data",
+     "getProjectedPointPosition": "get_projected_point_position",
+     "createProjectionAsExampleTable": "create_projection_as_example_table",
+     "createProjectionAsNumericArray": "create_projection_as_numeric_array",
+     "_getSum_i": "_getsum_i",
+     "normalizeExamples": "normalize_examples",
+     "anchorData": "anchor_data",
+     "lastAttrIndices": "last_attr_indices",
+     "anchorDict": "anchor_dict"})
 class ScaleLinProjData(ScaleData):
     def __init__(self):
         ScaleData.__init__(self)
@@ -896,23 +911,20 @@ graph_deprecator = deprecated_members({"setData": "set_data",
                                        "updateData": "update_data",
                                        "scaleFactor": "scale_factor"})
 
-ScaleLinProjData = deprecated_members({"setAnchors": "set_anchors",
-                                       "createAnchors": "create_anchors",
-                                       "createXAnchors": "create_xanchors",
-                                       "createYAnchors": "create_yanchors",
-                                       "saveProjectionAsTabData": "save_projection_as_tab_data",
-                                       "getProjectedPointPosition":
-                                           "get_projected_point_position",
-                                       "createProjectionAsExampleTable":
-                                           "create_projection_as_example_table",
-                                       "createProjectionAsNumericArray":
-                                           "create_projection_as_numeric_array",
-                                       "_getSum_i": "_getsum_i",
-                                       "normalizeExamples": "normalize_examples",
-                                       "anchorData": "anchor_data",
-                                       "lastAttrIndices": "last_attr_indices",
-                                       "anchorDict": "anchor_dict"})(ScaleLinProjData)
 
+@deprecated_members(
+    {"setAnchors": "set_anchors",
+     "createAnchors": "create_anchors",
+     "saveProjectionAsTabData": "save_projection_as_tab_data",
+     "getProjectedPointPosition": "get_projected_point_position",
+     "createProjectionAsExampleTable": "create_projection_as_example_table",
+     "createProjectionAsNumericArray": "create_projection_as_numeric_array",
+     "_getSum_i": "_getsum_i",
+     "normalizeExamples": "normalize_examples",
+     "anchorData": "anchor_data",
+     "lastAttrIndices": "last_attr_indices",
+     "anchorDict": "anchor_dict",
+     "trueScaleFactor": "true_scale_factor"})
 class ScaleLinProjData3D(ScaleData):
     def __init__(self):
         ScaleData.__init__(self)
@@ -1258,23 +1270,11 @@ class ScaleLinProjData3D(ScaleData):
     
     _getSum_i = _getsum_i
 
-ScaleLinProjData3D = deprecated_members({"setAnchors": "set_anchors",
-                                       "createAnchors": "create_anchors",
-                                       "saveProjectionAsTabData": "save_projection_as_tab_data",
-                                       "getProjectedPointPosition":
-                                           "get_projected_point_position",
-                                       "createProjectionAsExampleTable":
-                                           "create_projection_as_example_table",
-                                       "createProjectionAsNumericArray":
-                                           "create_projection_as_numeric_array",
-                                       "_getSum_i": "_getsum_i",
-                                       "normalizeExamples": "normalize_examples",
-                                       "anchorData": "anchor_data",
-                                       "lastAttrIndices": "last_attr_indices",
-                                       "anchorDict": "anchor_dict",
-                                       "trueScaleFactor": "true_scale_factor"
-                                      })(ScaleLinProjData3D)
 
+@deprecated_members(
+    {"createProjectionAsExampleTable": "create_projection_as_example_table",
+     "createProjectionAsNumericArray": "create_projection_as_numeric_array",
+     "getProjectedPointPosition": "get_projected_point_position"})
 class ScalePolyvizData(ScaleLinProjData):
     def __init__(self):
         ScaleLinProjData.__init__(self)
@@ -1352,29 +1352,29 @@ class ScalePolyvizData(ScaleLinProjData):
             xanchors = self.create_xanchors(len(attr_indices))
             yanchors = self.create_yanchors(len(attr_indices))
 
-        xanchors = numpy.zeros(numpy.shape(selected_data), numpy.float)
-        yanchors = numpy.zeros(numpy.shape(selected_data), numpy.float)
+        xanchorpos = numpy.zeros(numpy.shape(selected_data), numpy.float)
+        yanchorpos = numpy.zeros(numpy.shape(selected_data), numpy.float)
         length = len(attr_indices)
 
         for i in range(length):
             if attribute_reverse[i]:
-                xanchors[i] = selected_data[i] * xanchors[i] + (1-selected_data[i]) * xanchors[(i+1)%length]
-                yanchors[i] = selected_data[i] * yanchors[i] + (1-selected_data[i]) * yanchors[(i+1)%length]
+                xanchorpos[i] = selected_data[i] * xanchors[i] + (1 - selected_data[i]) * xanchors[(i + 1) % length]
+                yanchorpos[i] = selected_data[i] * yanchors[i] + (1 - selected_data[i]) * yanchors[(i + 1) % length]
             else:
-                xanchors[i] = (1-selected_data[i]) * xanchors[i] + selected_data[i] * xanchors[(i+1)%length]
-                yanchors[i] = (1-selected_data[i]) * yanchors[i] + selected_data[i] * yanchors[(i+1)%length]
+                xanchorpos[i] = (1 - selected_data[i]) * xanchors[i] + selected_data[i] * xanchors[(i + 1) % length]
+                yanchorpos[i] = (1 - selected_data[i]) * yanchors[i] + selected_data[i] * yanchors[(i + 1) % length]
 
-        x_positions = numpy.sum(numpy.multiply(xanchors, selected_data), axis=0)/sum_i
-        y_positions = numpy.sum(numpy.multiply(yanchors, selected_data), axis=0)/sum_i
-        #x_positions = numpy.sum(numpy.transpose(xanchors* numpy.transpose(selectedData)), axis=0) / sum_i
-        #y_positions = numpy.sum(numpy.transpose(yanchors* numpy.transpose(selectedData)), axis=0) / sum_i
+        x_positions = numpy.sum(numpy.multiply(xanchorpos, selected_data), axis=0) / sum_i
+        y_positions = numpy.sum(numpy.multiply(yanchorpos, selected_data), axis=0) / sum_i
+        #x_positions = numpy.sum(numpy.transpose(xanchorpos * numpy.transpose(selectedData)), axis=0) / sum_i
+        #y_positions = numpy.sum(numpy.transpose(yanchorpos * numpy.transpose(selectedData)), axis=0) / sum_i
 
         if scale_factor != 1.0:
             x_positions = x_positions * scale_factor
             y_positions = y_positions * scale_factor
         if jitter_size > 0.0:
-            x_positions += (numpy.random.random(len(x_positions))-0.5)*jitter_size
-            y_positions += (numpy.random.random(len(y_positions))-0.5)*jitter_size
+            x_positions += (numpy.random.random(len(x_positions)) - 0.5) * jitter_size
+            y_positions += (numpy.random.random(len(y_positions)) - 0.5) * jitter_size
 
         if class_list != None:
             return numpy.transpose(numpy.array((x_positions, y_positions, class_list)))
@@ -1432,14 +1432,18 @@ class ScalePolyvizData(ScaleLinProjData):
     
     getProjectedPointPosition = get_projected_point_position
 
-ScalePolyvizData = deprecated_members({"createProjectionAsExampleTable":
-                                           "create_projection_as_example_table",
-                                       "createProjectionAsNumericArray":
-                                           "create_projection_as_numeric_array",
-                                       "getProjectedPointPosition":
-                                           "get_projected_point_position"
-                                       })(ScalePolyvizData)
 
+@deprecated_members(
+    {"getOriginalData": "get_original_data",
+     "getOriginalSubsetData": "get_original_subset_data",
+     "getXYDataPositions": "get_xy_data_positions",
+     "getXYSubsetDataPositions": "get_xy_subset_data_positions",
+     "getProjectedPointPosition": "get_projected_point_position",
+     "createProjectionAsExampleTable": "create_projection_as_example_table",
+     "createProjectionAsExampleTable3D": "create_projection_as_example_table_3D",
+     "createProjectionAsNumericArray": "create_projection_as_numeric_array",
+     "createProjectionAsNumericArray3D": "create_projection_as_numeric_array_3D",
+     "getOptimalClusters": "get_optimal_clusters"})
 class ScaleScatterPlotData(ScaleData):
     def get_original_data(self, indices):
         data = self.original_data.take(indices, axis = 0)
@@ -1705,15 +1709,3 @@ class ScaleScatterPlotData(ScaleData):
         self.scatterWidget.progressBarFinished()
     
     getOptimalClusters = get_optimal_clusters
-
-ScaleScatterPlotData = deprecated_members({"getOriginalData": "get_original_data",
-                                           "getOriginalSubsetData": "get_original_subset_data",
-                                           "getXYDataPositions": "get_xy_data_positions",
-                                           "getXYSubsetDataPositions": "get_xy_subset_data_positions",
-                                           "getProjectedPointPosition": "get_projected_point_position",
-                                           "createProjectionAsExampleTable": "create_projection_as_example_table",
-                                           "createProjectionAsExampleTable3D": "create_projection_as_example_table_3D",
-                                           "createProjectionAsNumericArray": "create_projection_as_numeric_array",
-                                           "createProjectionAsNumericArray3D": "create_projection_as_numeric_array_3D",
-                                           "getOptimalClusters": "get_optimal_clusters"
-                                           })(ScaleScatterPlotData)
