@@ -1,11 +1,12 @@
 from math import sqrt, floor
-import Orange.core as orange
+
 import Orange
 import Orange.feature.scoring
 import random
 import copy
 from Orange.utils import deprecated_keywords
 from operator import add
+import Orange.core
 
 def _default_small_learner(attributes=None, rand=None, base=None):
     # tree learner assembled as suggested by Breiman (2001)
@@ -28,7 +29,8 @@ def _wrap_learner(base, rand, randorange):
         return _default_small_learner(None, rand, base)
     else:
         notRightLearnerToWrap()
- 
+
+
 class _RandomForestSimpleTreeLearner(Orange.core.Learner):
     """A learner which wraps an ordinary SimpleTreeLearner.  Sets the
     skip_prob so that the number of randomly chosen features for each
@@ -40,7 +42,8 @@ class _RandomForestSimpleTreeLearner(Orange.core.Learner):
         self.base = base
         self.attributes = None
         self.rand = rand
-    
+
+    @deprecated_keywords({"examples": "instances", "weightID": "weight"})
     def __call__(self, instances, weight=0):
         osp,orand = self.base.skip_prob, self.base.random_generator
         self.base.skip_prob = 1-float(self.attributes)/len(instances.domain.attributes)
@@ -49,7 +52,6 @@ class _RandomForestSimpleTreeLearner(Orange.core.Learner):
         self.base.skip_prob, self.base.random_generator = osp, orand
         return r
 
-_RandomForestSimpleTreeLearner = Orange.utils.deprecated_members({"weightID":"weight_id", "examples":"instances"})(_RandomForestSimpleTreeLearner)
 
 class _RandomForestTreeLearner(Orange.core.Learner):
     """ A learner which wraps an ordinary TreeLearner with
@@ -65,7 +67,7 @@ class _RandomForestTreeLearner(Orange.core.Learner):
         if not self.rand: #for all the built trees
             self.rand = random.Random(0)
 
-    @deprecated_keywords({"examples":"instances"})
+    @deprecated_keywords({"examples": "instances"})
     def __call__(self, instances, weight=0):
         """ A current tree learner is copied, modified and then used.
         Modification: set a different split constructor, which uses
@@ -85,7 +87,6 @@ class _RandomForestTreeLearner(Orange.core.Learner):
         return bcopy(instances, weight=weight)
 
 
-
 class RandomForestLearner(Orange.core.Learner):
     """
     Trains an ensemble predictor consisting of trees trained
@@ -163,6 +164,7 @@ class RandomForestLearner(Orange.core.Learner):
            
         self.randstate = self.rand.getstate() #original state
 
+    @deprecated_keywords({"examples": "instances"})
     def __call__(self, instances, weight=0):
         """
         Learn from the given table of data instances.
@@ -200,9 +202,8 @@ class RandomForestLearner(Orange.core.Learner):
                     class_vars=instances.domain.class_vars)
 
 
-RandomForestLearner = Orange.utils.deprecated_members({"examples":"instances"})(RandomForestLearner)
-
-class RandomForestClassifier(orange.Classifier):
+@Orange.utils.deprecated_members({"classVar": "class_var"})
+class RandomForestClassifier(Orange.core.Classifier):
     """
     Uses the trees induced by the :obj:`RandomForestLearner`. An input
     instance is classified into the class with the most frequent vote.
@@ -237,7 +238,9 @@ class RandomForestClassifier(orange.Classifier):
         self.__dict__.update(kwds)
         self.single_class = True if not class_vars else False
 
-    def __call__(self, instance, result_type = orange.GetValue):
+    @Orange.utils.deprecated_keywords(
+        {"example": "instance", "resultType": "result_type"})
+    def __call__(self, instance, result_type = Orange.classification.Classifier.GetValue):
         """
         :param instance: instance to be classified.
         :type instance: :class:`Orange.data.Instance`
@@ -249,9 +252,9 @@ class RandomForestClassifier(orange.Classifier):
         :rtype: :class:`Orange.data.Value`, 
               :class:`Orange.statistics.Distribution` or a tuple with both
         """
-
+        instance = Orange.data.Instance(self.domain, instance)
         # get results to avoid multiple calls
-        res_both = [c(instance, orange.GetBoth) for c in self.classifiers]
+        res_both = [c(instance, Orange.classification.Classifier.GetBoth) for c in self.classifiers]
 
         # transform single class instance to match multi-target instances
         if self.single_class:
@@ -270,7 +273,7 @@ class RandomForestClassifier(orange.Classifier):
             if self.class_var.var_type == Orange.feature.Discrete.Discrete:
         
                 # voting for class probabilities
-                if result_type == orange.GetProbabilities or result_type == orange.GetBoth:
+                if result_type == Orange.classification.Classifier.GetProbabilities or result_type == Orange.classification.Classifier.GetBoth:
                     prob = [0.] * len(self.class_var.values)
                     for r in res_both:
                         a = [x for x in r[1][varn]]
@@ -283,15 +286,15 @@ class RandomForestClassifier(orange.Classifier):
                 # voting for crisp class membership, notice that
                 # this may not be the same class as one obtaining the
                 # highest probability through probability voting
-                if result_type == orange.GetValue or result_type == orange.GetBoth:
+                if result_type == Orange.classification.Classifier.GetValue or result_type == Orange.classification.Classifier.GetBoth:
                     cfreq = [0] * len(self.class_var.values)
                     for r in res_both:
                         cfreq[int(r[0][varn])] += 1
                     index = cfreq.index(max(cfreq))
                     cvalue = Orange.data.Value(self.class_var, index)
             
-                if result_type == orange.GetValue: mt_value.append(cvalue)
-                elif result_type == orange.GetProbabilities: mt_prob.append(cprob)
+                if result_type == Orange.classification.Classifier.GetValue: mt_value.append(cvalue)
+                elif result_type == Orange.classification.Classifier.GetProbabilities: mt_prob.append(cprob)
                 else: 
                     mt_value.append(cvalue)
                     mt_prob.append(cprob)
@@ -300,7 +303,7 @@ class RandomForestClassifier(orange.Classifier):
                 # Handle continuous class
         
                 # voting for class probabilities
-                if result_type == orange.GetProbabilities or result_type == orange.GetBoth:
+                if result_type == Orange.classification.Classifier.GetProbabilities or result_type == Orange.classification.Classifier.GetBoth:
                     probs = [ r for r in res_both]
                     cprob = dict()
       
@@ -314,35 +317,34 @@ class RandomForestClassifier(orange.Classifier):
                     cprob.normalize()
                 
                 # gather average class value
-                if result_type == orange.GetValue or result_type == orange.GetBoth:
+                if result_type == Orange.classification.Classifier.GetValue or result_type == Orange.classification.Classifier.GetBoth:
                     values = [r[0][varn] for r in res_both]
                     cvalue = Orange.data.Value(self.class_var, sum(values) / len(self.classifiers))
             
-                if result_type == orange.GetValue: mt_value.append(cvalue)
-                elif result_type == orange.GetProbabilities: mt_prob.append(cprob)
+                if result_type == Orange.classification.Classifier.GetValue: mt_value.append(cvalue)
+                elif result_type == Orange.classification.Classifier.GetProbabilities: mt_prob.append(cprob)
                 else: 
                     mt_value.append(cvalue)
                     mt_prob.append(cprob)
         
         # check for singleclass when returning
         if self.single_class:
-            if result_type == orange.GetValue: return mt_value[0]
-            elif result_type == orange.GetProbabilities: return mt_prob[0]
+            if result_type == Orange.classification.Classifier.GetValue: return mt_value[0]
+            elif result_type == Orange.classification.Classifier.GetProbabilities: return mt_prob[0]
             else: 
                 return [mt_value[0],mt_prob[0]] 
             
-        if result_type == orange.GetValue: return tuple(mt_value)
-        elif result_type == orange.GetProbabilities: return tuple(mt_prob)
+        if result_type == Orange.classification.Classifier.GetValue: return tuple(mt_value)
+        elif result_type == Orange.classification.Classifier.GetProbabilities: return tuple(mt_prob)
         else: 
             return [tuple(mt_value),tuple(mt_prob)]
 
     def __reduce__(self):
         return type(self), (self.classifiers, self.name, self.domain, self.class_var, self.class_vars), dict(self.__dict__)
 
-RandomForestClassifier = Orange.utils.deprecated_members({"resultType":"result_type", "classVar":"class_var", "example":"instance"})(RandomForestClassifier)
 ### MeasureAttribute_randomForests
 
-class ScoreFeature(orange.MeasureAttribute):
+class ScoreFeature(Orange.feature.scoring.Score):
     """
     :param trees: number of trees in the forest.
     :type trees: int
@@ -547,7 +549,7 @@ class ScoreFeature(orange.MeasureAttribute):
           return set([])
 
 
-class SplitConstructor_AttributeSubset(orange.TreeSplitConstructor):
+class SplitConstructor_AttributeSubset(Orange.classification.tree.SplitConstructor):
     def __init__(self, scons, attributes, rand = None):
         self.scons = scons           # split constructor of original tree
         self.attributes = attributes # number of features to consider
