@@ -1,5 +1,4 @@
-import Orange.core as orange
-from orange import\
+from Orange.core import\
     Imputer as Imputer,\
     ImputerConstructor as Constructor,\
     ImputerConstructor_minimal as MinimalConstructor,\
@@ -15,17 +14,24 @@ from orange import\
     ImputeClassifier as Classifier
 
 import Orange.misc
+import Orange
 
-class ImputeLearner(orange.Learner):
-    def __new__(cls, data = None, weight_id = 0, **keyw):
-        self = orange.Learner.__new__(cls, **keyw)
+
+@Orange.utils.deprecated_members(
+  {"dontImputeClassifier": "dont_impute_classifier",
+   "imputerConstructor": "imputer_constructor",
+   "baseLearner": "base_learner"})
+class ImputeLearner(Orange.classification.Learner):
+    def __new__(cls, data=None, weight_id=0, **keyw):
+        self = Orange.classification.Learner.__new__(cls, **keyw)
         self.dont_impute_classifier = False
         self.__dict__.update(keyw)
-        if data:
+        if data is not None:
             return self.__call__(data, weight_id)
         else:
             return self
-        
+
+    @Orange.utils.deprecated_keywords({"weightID": "weight_id"})
     def __call__(self, data, weight=0):
         trained_imputer = self.imputer_constructor(data, weight)
         imputed_data = trained_imputer(data, weight)
@@ -35,25 +41,13 @@ class ImputeLearner(orange.Learner):
         else:
             return ImputeClassifier(base_classifier, trained_imputer)
 
-ImputeLearner = Orange.utils.deprecated_members(
-  {
-      "dontImputeClassifier": "dont_impute_classifier",
-      "imputerConstructor": "imputer_constructor",
-      "baseLearner": "base_learner",
-      "weightID": "weight_id"
-  })(ImputeLearner)
 
-
-class ImputeClassifier(orange.Classifier):
+@Orange.utils.deprecated_members({"baseClassifier": "base_classifier"})
+class ImputeClassifier(Orange.classification.Classifier):
     def __init__(self, base_classifier, imputer, **argkw):
         self.base_classifier = base_classifier
         self.imputer = imputer
         self.__dict__.update(argkw)
 
-    def __call__(self, i, what=orange.GetValue):
+    def __call__(self, i, what=Orange.classification.Classifier.GetValue):
         return self.base_classifier(self.imputer(i), what)
-
-ImputeClassifier = Orange.utils.deprecated_members(
-  {
-      "baseClassifier": "base_classifier"
-  })(ImputeClassifier)
