@@ -84,7 +84,6 @@ from functools import wraps
 import itertools
 from functools import partial
 
-import orange
 from Orange.data import preprocess
 
 TEST_CLASSIFICATION = 1
@@ -103,12 +102,12 @@ CONTINUIZE_DOMAIN = 32
 def open_data(name, flags=0):
     """ Open a named data-set return it. 
     """
-    dataset = orange.ExampleTable(name)
+    dataset = Orange.data.Table(name)
     if flags & CONTINUIZE_DOMAIN:
         preprocessor = preprocess.Continuize()
         dataset = preprocessor(dataset)
     elif flags & DISCRETIZE_DOMAIN:
-        preprocessor = preprocess.Discretize(method=orange.EquiNDiscretization(),
+        preprocessor = preprocess.Discretize(method=Orange.feature.discretization.EqualFreq(),
                                                discretize_class=False)
         dataset = preprocessor(dataset)
     dataset.name = name
@@ -410,25 +409,46 @@ class LearnerTestCase(DataTestCase):
     def test_pickling_on(self, dataset):
         """ Test learner and classifier pickling.
         """
+        def clone(obj):
+            return pickle.loads(pickle.dumps(obj))
+
+        cloned_learner = clone(self.learner)
         classifier = self.learner(dataset)
+        classifier_clone = clone(classifier)
+        classifier_from_cloned = cloned_learner(dataset)
 
-        s = pickle.dumps(classifier)
-        classifier_clone = pickle.loads(s)
-
-        indices = orange.MakeRandomIndices2(p0=20)(dataset)
+        indices = Orange.data.sample.SubsetIndices2(p0=20)(dataset)
         test = dataset.select(indices, 0)
+        class_var = dataset.domain.class_var
 
         for ex in test:
-            if isinstance(dataset.domain.class_var, Orange.feature.Continuous):
+            prediction1 = classifier(ex, Orange.classification.Classifier.GetValue)
+            prediction2 = classifier_clone(ex, Orange.classification.Classifier.GetValue)
+            prediction3 = classifier_from_cloned(ex, Orange.classification.Classifier.GetValue)
+
+            if isinstance(class_var, Orange.feature.Continuous):
                 # Test to third digit after the decimal point
-                self.assertAlmostEqual(classifier(ex, orange.GetValue).native(),
-                                       classifier_clone(ex, orange.GetValue).native(),
-                                       min(3, dataset.domain.class_var.number_of_decimals),
-                                       "Pickled and original classifier return a different value!")
+                self.assertAlmostEqual(
+                    prediction1.native(), prediction2.native(),
+                    min(3, class_var.number_of_decimals),
+                    "Pickled and original classifier return a different "
+                    "value!")
+
+                self.assertAlmostEqual(
+                    prediction1.native(), prediction3.native(),
+                    min(3, class_var.number_of_decimals),
+                    "Pickled and original learner return a different "
+                    "classifier!")
             else:
-                self.assertEqual(classifier(ex, orange.GetValue),
-                                 classifier_clone(ex, orange.GetValue),
-                                 "Pickled and original classifier return a different value!")
+                self.assertEqual(
+                    prediction1, prediction2,
+                    "Pickled and original classifier return a different "
+                    "value!")
+
+                self.assertEqual(
+                    prediction1, prediction3,
+                    "Pickled and original learner return a different "
+                    "classifier!")
 
 
 class MeasureAttributeTestCase(DataTestCase):
@@ -508,7 +528,7 @@ class DistanceTestCase(DataTestCase):
     @test_on_data
     def test_distance_on(self, dataset):
         import numpy
-        indices = orange.MakeRandomIndices2(dataset, min(20, len(dataset)))
+        indices = Orange.data.sample.SubsetIndices2(dataset, min(20, len(dataset)))
         dataset = dataset.select(indices, 0)
         with member_set(self.distance_constructor, "ignore_class", True):
             mat = distance_matrix(dataset, self.distance_constructor)
@@ -523,7 +543,7 @@ class DistanceTestCase(DataTestCase):
             with member_set(self.distance_constructor, "ignore_class", False):
                 try:
                     mat = distance_matrix(dataset, self.distance_constructor)
-                except orange.KernelException, ex:
+                except Orange.core.KernelException, ex:
                     if "not supported" in str(ex):
                         return
                     else:
@@ -613,7 +633,7 @@ try:
     __IPYTHON__  #We are running tests from ipython
     if getattr(__IPYTHON__.shell, "call_pdb", None): # Is pdb enabled
         enable_pdb()
-except NameError:
+except:
     pass
 
 
