@@ -7,6 +7,8 @@ import Orange.misc
 from Orange.utils import deprecated_class_attribute, deprecated_keywords, \
                          deprecated_members
 
+
+@deprecated_members({"returnWhat": "return_what", "object": "learner"})
 class TuneParameters(Orange.classification.Learner):
 
     """.. attribute:: data
@@ -94,7 +96,7 @@ class TuneParameters(Orange.classification.Learner):
     @deprecated_keywords({"examples": "data", "weightID": "weight_id"})
     def __new__(cls, data=None, weight_id=0, **argkw):
         self = Orange.classification.Learner.__new__(cls, **argkw)
-        if data:
+        if data is not None:
             for name, value in argkw.items():
                 setattr(self, name, value)
             self.__init__(**argkw)
@@ -110,11 +112,6 @@ class TuneParameters(Orange.classification.Learner):
             lastobj = getattr(lastobj, i)
         return lastobj, names[-1]
 
-TuneParameters = deprecated_members(
-    {"returnWhat": "return_what",
-     "object": "learner"},
-    )(TuneParameters)
-
 
 class Tune1Parameter(TuneParameters):
 
@@ -220,6 +217,8 @@ class Tune1Parameter(TuneParameters):
             classifier.setattr("fitted_parameter", bestpar)
             return classifier
 
+
+@deprecated_members({"progressCallback": "progress_callback"})
 class TuneMParameters(TuneParameters):
 
     """The use of :obj:`Orange.optimization.TuneMParameters` differs from 
@@ -308,10 +307,8 @@ class TuneMParameters(TuneParameters):
             classifier.fitted_parameters = bestpar
             return classifier
 
-TuneMParameters = deprecated_members(
-    {"progressCallback": "progress_callback"},
-    )(TuneMParameters)
 
+@deprecated_members({"storeCurve": "store_curve"}, wrap_methods=["__init__"])
 class ThresholdLearner(Orange.classification.Learner):
 
     """:obj:`Orange.optimization.ThresholdLearner` is a class that wraps 
@@ -345,7 +342,7 @@ class ThresholdLearner(Orange.classification.Learner):
     @deprecated_keywords({"examples": "data", "weightID": "weight_id"})
     def __new__(cls, data=None, weight_id=0, **kwds):
         self = Orange.classification.Learner.__new__(cls, **kwds)
-        if data:
+        if data is not None:
             self.__init__(**kwargs)
             return self.__call__(data, weight_id)
         else:
@@ -372,10 +369,6 @@ class ThresholdLearner(Orange.classification.Learner):
         else:
             return ThresholdClassifier(classifier, threshold)
 
-ThresholdLearner = deprecated_members(
-    {"storeCurve": "store_curve"},
-    wrap_methods=["__init__"]
-    )(ThresholdLearner)
 
 class ThresholdClassifier(Orange.classification.Classifier):
 
@@ -442,7 +435,7 @@ class ThresholdLearner_fixed(Orange.classification.Learner):
     @deprecated_keywords({"examples": "data", "weightID": "weight_id"})
     def __new__(cls, data=None, weight_id=0, **kwds):
         self = Orange.classification.Learner.__new__(cls, **kwds)
-        if data:
+        if data is not None:
             self.__init__(**kwds)
             return self.__call__(data, weight_id)
         else:
